AdContentInfo class

Contains information about the loaded ad.

Constructors

AdContentInfo({required AdFormat format, required String sourceName, required String sourceUnitId, required String? creativeId, required double revenue, required AdRevenuePrecision revenuePrecision, required double revenueTotal, required int impressionDepth})
Constructs a AdContentInfo

Properties

creativeId String?
The Creative ID associated with the ad, or null if not available.
final
hashCode int
The hash code for this object.
no setterinherited
impressionDepth int
The total number of impressions across all ad formats for the current user, across all sessions.
final
revenue double
The revenue generated from the impression, in USD.
final
revenuePrecision AdRevenuePrecision
The precision type of the revenue field.
final
revenueTotal double
The accumulated value of user ad revenue in USD from all ad format impressions.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
sourceName String
The display name of the mediated network that purchased the impression.
final
sourceUnitId String
The Ad Unit ID from the mediated network that purchased the impression.
final

Methods

getCreativeId() Future<String?>
Gets the Creative ID associated with the ad, if available. May be null.
getFormat() Future<AdFormat>
Gets the format of the ad that is shown.
getImpressionDepth() Future<int>
Gets the total number of impressions across all ad formats for the current user, across all sessions.
getRevenue() Future<double>
Gets the revenue generated from the impression, in USD.
getRevenuePrecision() Future<AdRevenuePrecision>
Gets the precision type of the revenue field.
getRevenueTotal() Future<double>
Gets the accumulated value of user ad revenue in USD from all ad format impressions.
getSourceName() Future<String>
Gets the display name of the mediated network that purchased the impression.
getSourceUnitId() Future<String>
Gets the Ad Unit ID from the mediated network that purchased the impression.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited