AdImpression class

Annotations
  • @Deprecated("Please use the new features of CAS with AdContentInfo.")

Constructors

AdImpression({required AdType adType, required double cpm, required String network, required PriceAccuracy priceAccuracy, required String versionInfo, required String? creativeIdentifier, required String identifier, required int impressionDepth, required double lifetimeRevenue})

Properties

adType AdType
final
cpm double
final
creativeIdentifier String?
final
hashCode int
The hash code for this object.
no setterinherited
identifier String
final
impressionDepth int
final
lifetimeRevenue double
final
network String
final
priceAccuracy PriceAccuracy
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
versionInfo String
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
override

Operators

operator ==(Object other) bool
The equality operator.
inherited