getContentInfo method
Contains information about the loaded request.
Only present if the ad has been successfully loaded.
Implementation
Future<AdContentInfo?> getContentInfo() {
return casInternalBridge.getContentInfo(this);
}
Contains information about the loaded request.
Only present if the ad has been successfully loaded.
Future<AdContentInfo?> getContentInfo() {
return casInternalBridge.getContentInfo(this);
}