onAdClicked property

OnAdCallback? onAdClicked
getter/setter pair

Called when the ad content is clicked by the user.

This function provides an opportunity to handle user clicks on the ad, such as tracking click events or updating the UI.

Implementation

OnAdCallback? onAdClicked;