onAdFailedToLoad property

OnAdFailedCallback? onAdFailedToLoad
getter/setter pair

Called when the ad content fails to load.

This function provides an opportunity to handle loading failures, such as displaying an error message to the user or attempting to load a different ad.

Implementation

OnAdFailedCallback? onAdFailedToLoad;