onAdImpression property
Callback to be invoked when an ad is estimated to have earned money. Available for allowlisted accounts only.
Implementation
OnAdContentCallback? onAdImpression;
Callback to be invoked when an ad is estimated to have earned money. Available for allowlisted accounts only.
OnAdContentCallback? onAdImpression;