placement property
An optional placement name for the ad instance that helps categorize and track statistics across different ad placements.
Implementation
final String? placement;
An optional placement name for the ad instance that helps categorize and track statistics across different ad placements.
final String? placement;