dispose method
The dispose function should be called from onAdFailedToShow and onAdDismissed to free up resources if you do not expect automatic loading and will not load this instance again.
Implementation
@override
void dispose() {
super.dispose();
onAdLoaded = null;
onAdShowed = null;
onAdFailedToShow = null;
onAdDismissed = null;
// ignore: deprecated_member_use_from_same_package
contentCallback = null;
// ignore: deprecated_member_use_from_same_package
impressionListener = null;
}