load method
Manual retry to load the ad.
If AdScreenInstance.isAutoloadEnabled is enabled, this function will be called automatically when necessary.
Implementation
Future<void> load() {
return casInternalBridge.loadAd(this);
}
Manual retry to load the ad.
If AdScreenInstance.isAutoloadEnabled is enabled, this function will be called automatically when necessary.
Future<void> load() {
return casInternalBridge.loadAd(this);
}