onAdDismissed property
Called when the ad content is dismissed.
This function is triggered when the ad content is closed or dismissed by the user. Use this method to perform any necessary actions after the ad has been dismissed, such as cleaning up resources or updating the UI.
Implementation
OnScreenAdCallback? onAdDismissed;