onAdFailedToShow property

OnAdFailedCallback? onAdFailedToShow
getter/setter pair

Called when the ad content fails to show.

This function is triggered if there is an issue displaying the ad content. Implement this method to handle errors related to ad presentation, such as retrying the display or notifying the user.

Implementation

OnAdFailedCallback? onAdFailedToShow;