onAdLoaded property

OnScreenAdCallback? onAdLoaded
getter/setter pair

Called when the ad content has been successfully loaded.

This function provides an opportunity to handle successful ad loading, such as preparing the ad for display.

Implementation

OnScreenAdCallback? onAdLoaded;