onAdShowed property

OnScreenAdCallback? onAdShowed
getter/setter pair

Called when the ad content is successfully shown.

This function is triggered when the ad content has been successfully displayed. Use this function to perform any actions required after the ad is shown, such as logging or UI updates.

Implementation

OnScreenAdCallback? onAdShowed;