show method

Future<void> show()

Display this on top of the application.

Set ad callbacks before calling this method to be notified of events that occur when showing the ad.

Implementation

Future<void> show() {
  return casInternalBridge.showScreenAd(this);
}