AdViewListener class

WARNING: This API is still supported but no longer recommended. Migrate to new CASWidget with CASBanner implementation.

Annotations
  • @Deprecated("Please migrate to new CASBanner.createAndLoad() and CASWidget")

Constructors

AdViewListener({dynamic onAdViewLoaded()?, dynamic onAdViewFailed(String? message)?, dynamic onAdViewPresented()?, dynamic onAdViewClicked()?})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
onAdViewClicked → void Function()?
Invokes this callback when a user clicks the ad.
final
onAdViewFailed → void Function(String? message)?
Invokes this callback when an error occurred with the ad.
final
onAdViewLoaded → void Function()?
Invokes this callback when ad loaded and ready to present.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited