Audience enum

Prohibition on Personal Information from Children

Inheritance
Available extensions

Values

undefined → const Audience

If your app's target age groups include both children and older audiences, any ads that may be shown to children must comply with Google Play's Families Ads Program.

A neutral age screen must be implemented so that any ads not suitable for children are only shown to older audiences. A neutral age screen is a mechanism to verify a user's age in a way that doesn't encourage them to falsify their age and gain access to areas of your app that aren't designed for children, for example, an age gate.

children → const Audience

Compliance with all applicable legal regulations and industry standards relating to advertising to children.

notChildren → const Audience

Audiences over the age of 13 NOT subject to the restrictions of child protection laws.

Properties

hashCode int
The hash code for this object.
no setterinherited
index int
A numeric identifier for the enumerated value.
no setterinherited
name String

Available on Enum, provided by the EnumName extension

The name of the enum value.
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Constants

values → const List<Audience>
A constant List of the values in this enum, in order of their declaration.