CAS class

WARNING: This API is still supported but no longer recommended. Migrate to new CASMobileAds implementation.

Constructors

CAS()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

settings AdsSettings
Get singleton instance for configure all mediation managers
final
targetingOptions TargetingOptions
You can now easily tailor the way you serve your ads to fit a specific audience! You’ll need to inform our servers of the users’ details so the SDK will know to serve ads according to the segment the user belongs to.
no setter

Static Methods

buildConsentFlow() ConsentFlow
Create ConsentFlow.
buildManager() ManagerBuilder
Create MediationManager builder. Don't forget to call the ManagerBuilder.build method to create manager instance.
getCPPAStatus() Future<CCPAStatus>
getInterstitialInterval() Future<int>
getSDKVersion() Future<String>
getTaggedAudience() Future<Audience>
restartInterstitialInterval() Future<void>
setAge(int age) Future<void>
setCCPAStatus(CCPAStatus status) Future<void>
setDebugMode(bool isEnable) Future<void>
setGender(Gender gender) Future<void>
setInterstitialInterval(int delay) Future<void>
setLoadingMode(LoadingMode loadingMode) Future<void>
setMutedAdSounds(bool mute) Future<void>
setTaggedAudience(Audience audience) Future<void>
validateIntegration() Future<void>
Call Integration Helper and check current integration in logcat(Android) or console(iOS). LOG TAG: CASIntegrationHelper