validateIntegration static method

Future<void> validateIntegration()

Call Integration Helper and check current integration in logcat(Android) or console(iOS). LOG TAG: CASIntegrationHelper

Call Integration Helper and check current integration in console. Log tag: CASIntegrationHelper

Implementation

static Future<void> validateIntegration() {
  return casInternalBridge.validateIntegration();
}