setAutoshowEnabled method
Controls whether the ad should be automatically displayed when the user returns to the app.
Note that the ad must be ready for display at the time of returning to the app.
Implementation
Future<void> setAutoshowEnabled(bool isEnabled) {
return casInternalBridge.setAutoshowEnabled(this, isEnabled);
}