CASInterstitial class

Manages an interstitial ad, allowing for loading, showing, and destroying the ad content.

This class provides functionality to handle interstitial ads, which are full-screen ads that cover the entire screen and are typically used at natural transition points within an app.

Inheritance

Constructors

CASInterstitial.create(String casId)
Create new Interstitial Instance
CASInterstitial.createAndLoad({String? casId, bool autoReload = false, bool autoShow = false, int? minInterval, String? placement, OnScreenAdCallback? onAdLoaded, OnAdFailedCallback? onAdFailedToLoad, OnAdFailedCallback? onAdFailedToShow, OnScreenAdCallback? onAdShowed, OnAdContentCallback? onAdImpression, OnAdCallback? onAdClicked, OnScreenAdCallback? onAdDismissed})
Create CASInterstitial and load ad content.

Properties

contentCallback ScreenAdContentCallback?
Gets or sets the callback for handling ad content events.
getter/setter pairinherited
format AdFormat
The ad format of this instance.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
impressionListener OnAdImpressionListener?
Listener to be invoked when an ad is estimated to have earned money. Available for allowlisted accounts only.
getter/setter pairinherited
onAdClicked OnAdCallback?
Called when the ad content is clicked by the user.
getter/setter pairinherited
onAdDismissed OnScreenAdCallback?
Called when the ad content is dismissed.
getter/setter pairinherited
onAdFailedToLoad OnAdFailedCallback?
Called when the ad content fails to load.
getter/setter pairinherited
onAdFailedToShow OnAdFailedCallback?
Called when the ad content fails to show.
getter/setter pairinherited
onAdImpression OnAdContentCallback?
Callback to be invoked when an ad is estimated to have earned money. Available for allowlisted accounts only.
getter/setter pairinherited
onAdLoaded OnScreenAdCallback?
Called when the ad content has been successfully loaded.
getter/setter pairinherited
onAdShowed OnScreenAdCallback?
Called when the ad content is successfully shown.
getter/setter pairinherited
placement String?
An optional placement name for the ad instance that helps categorize and track statistics across different ad placements.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

dispose() → void
The dispose function should be called from onAdFailedToShow and onAdDismissed to free up resources if you do not expect automatic loading and will not load this instance again.
inherited
getContentInfo() Future<AdContentInfo?>
Contains information about the loaded request.
inherited
getMinInterval() Future<int>
Gets the minimum interval between showing interstitial ads, in seconds.
isAutoloadEnabled() Future<bool>
Indicates whether the auto reload ad is currently enabled.
inherited
isAutoshowEnabled() Future<bool>
Indicates whether the auto show ad is currently enabled.
isLoaded() Future<bool>
Indicates whether the ad is currently loaded and ready to be shown.
inherited
load() Future<void>
Manual retry to load the ad.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
restartInterval() Future<void>
Restarts the interval countdown until the next interstitial ad display.
setAutoloadEnabled(bool isEnabled) Future<void>
Gets or sets whether auto loading of ads is enabled.
inherited
setAutoshowEnabled(bool isEnabled) Future<void>
Controls whether the ad should be automatically displayed when the user returns to the app.
setMinInterval(int minInterval) Future<void>
The minimum interval between showing interstitial ads, in seconds.
show() Future<void>
Display this on top of the application.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited