setOnDismissCallback method
- @Deprecated("Please set callback in create(onDismissed:) instead.")
- OnConsentFlowDismissedCallback callback
The callback is called after the form is dismissed. If consent is not required, the callback is called immediately. The Integer Status with which the form is dismissed will be passed to the callback.
Implementation
@Deprecated("Please set callback in create(onDismissed:) instead.")
ConsentFlow setOnDismissCallback(OnConsentFlowDismissedCallback callback) {
onDismissed = callback;
return this;
}