statusUnknown constant
int
const statusUnknown
There was no attempt to show the consent flow.
Implementation
static const statusUnknown = 0;
There was no attempt to show the consent flow.
static const statusUnknown = 0;