MediationManager class
WARNING: This API is still supported but no longer recommended. Migrate to new CASMobileAds implementation.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
disableAppReturn(
) → Future< void> - Disable the Return Ad which is displayed once the user returns to your application after a certain period of time.
-
enableAppReturn(
AdCallback? callback) → Future< void> - The Return Ad which is displayed once the user returns to your application after a certain period of time. To minimize the intrusiveness, short time periods are ignored.
-
getManagerID(
) → Future< String> - CAS manager (Placement) identifier
-
isDemoAdMode(
) → Future< bool> - Is test mode enabled
-
isEnabled(
int adType) → Future< bool> -
Ad
typeis processing. -
isFullscreenAdVisible(
) → Future< bool> - Check is visible AdType.interstitial or AdType.rewarded right now.
-
isInterstitialReady(
) → Future< bool> - Check if Interstitial ad is ready to be shown.
-
isRewardedAdReady(
) → Future< bool> - Check if Rewarded ad is ready to be shown.
-
loadInterstitial(
) → Future< void> - Manual load Interstitial Ad.
-
loadRewarded(
) → Future< void> - Manual load Rewarded Video Ad.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
setAdLoadCallback(
AdLoadCallback? callback) → void - Set AdLoadCallback
-
setEnabled(
int adType, bool isEnable) → Future< void> -
Set
enabledadtypeto processing. The state will not be saved between sessions. -
showInterstitial(
AdCallback? callback) → Future< void> - Shows the Interstitial ad if available. @param activity The activity from which the Interstitial ad should be shown. @param callback The callback for Interstitial ad events.
-
showRewarded(
AdCallback? callback) → Future< void> - Shows the Rewarded ad if available. @param activity The activity from which the Rewarded ad should be shown. @param callback The callback for Rewarded ad events.
-
skipNextAppReturnAds(
) → Future< void> - Calling this method will indicate to skip one next ad impression when returning to the app.
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited