OnAdCallback typedef
OnAdCallback =
void Function(AdInstance ad)
The callback type to handle an event occurring for an AdInstance.
Implementation
typedef OnAdCallback = void Function(AdInstance ad);
The callback type to handle an event occurring for an AdInstance.
typedef OnAdCallback = void Function(AdInstance ad);