OnAdImpressionListener class

A functional interface for listening to ad impression events. Implement this interface to handle actions when an ad impression is recorded.

Annotations
  • @Deprecated("Replaced with onAdImpression callback.")

Constructors

OnAdImpressionListener(dynamic onAdImpression(AdContentInfo ad))

Properties

hashCode int
The hash code for this object.
no setterinherited
onAdImpression → void Function(AdContentInfo ad)
Called when an ad impression occurs.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited