OnDismissListener class

Annotations
  • @Deprecated('Please set callback in ConsentFlow.create(onDismissed:) instead. This listener always returns ConsentStatus.undefined.')

Constructors

OnDismissListener(dynamic onConsentFlowDismissed(ConsentStatus status))
const

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onConsentFlowDismissed(int status) → void
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited