onAdFailedToShow property
Called when the ad content fails to show.
This function is triggered if there is an issue displaying the ad content. Implement this method to handle errors related to ad presentation, such as retrying the display or notifying the user.
format The format of ad content.
error The error that occurred while attempting to show the ad content.
Implementation
final void Function(AdFormat format, AdError error)? onAdFailedToShow;