TargetingOptions class

The App/user targeting options.

Constructors

TargetingOptions()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
userId String?
The userID is a unique identifier supplied by your application and must be static for each user across sessions.
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
setAge(int age) Future<void>
The user’s age
setContentUrl(String? contentUrl) Future<void>
Sets the content URL for a web site whose content matches the app's primary content. This web site content is used for targeting and brand safety purposes.
setGender(Gender gender) Future<void>
Set targeting to user’s Gender.
setKeywords(Set<String>? keywords) Future<void>
A list of keywords, interests, or intents related to your application.
setLocation({required double latitude, required double longitude}) Future<void>
The user's current location.
setLocationCollectionEnabled(bool enabled) Future<void>
Collect from the device the latitude and longitude coordinated truncated to the hundredths decimal place. Collect only if your application already has the relevant end-user permissions. Does not collect if the target audience is children.
setUserId(String? userId) Future<void>
The userID is a unique identifier supplied by your application and must be static for each user across sessions.
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited