clever_ads_solutions library
Classes
- AdCallback
- A callback interface for handling advertisement events.
- AdContentInfo
- Contains information about the loaded ad.
- AdError
-
Use code to retrieve the error code.
Use message to get a human-readable error description.
See
codeconstants for all available error codes. - AdImpression
- AdInstance
- The base class for all ads formats.
- AdLoadCallback
- AdScreenInstance
- The base class for all full screen ads.
- AdSize
- AdSize represents the size of a banner ad.
- AdsSettings
- This API is still supported but no longer recommended. Migrate to new CASMobileAds implementation.
- AdTypeFlags
- WARNING: This API is still supported but no longer recommended. Migrate to new CASMobileAds implementation.
- AdViewInstance
- The base class for ads displayed in a CASWidget.
- AdViewListener
- WARNING: This API is still supported but no longer recommended. Migrate to new CASWidget with CASBanner implementation.
- BannerWidget
- WARNING: This API is still supported but no longer recommended. Migrate to new CASWidget with CASBanner implementation.
- BannerWidgetState
- CAS
- WARNING: This API is still supported but no longer recommended. Migrate to new CASMobileAds implementation.
- CASAppOpen
- Manages an app open ad, allowing for loading, showing, and destroying the ad content.
- CASBanner
- A banner ad.
- CASInterstitial
- Manages an interstitial ad, allowing for loading, showing, and destroying the ad content.
- CASMobileAds
- Represents the CAS.AI SDK.
- CASNativeContent
- A Native Ad Content.
- CASRewarded
- Manages a rewarded ad, allowing for loading, showing, and destroying the ad content.
- CASWidget
- Displays an AdViewInstance as a Flutter widget.
- ConsentFlow
- Use this object for configure Consent flow forms for GDPR.
- InitConfig
- InitializationStatus
- The status of the SDK initialization.
- ManagerBuilder
- This API is still supported but no longer recommended. Migrate to new CASMobileAds implementation.
- MediationManager
- WARNING: This API is still supported but no longer recommended. Migrate to new CASMobileAds implementation.
- NativeTemplateStyle
- Style options for native templates.
- OnAdImpressionListener
- A functional interface for listening to ad impression events. Implement this interface to handle actions when an ad impression is recorded.
- OnDismissListener
- OnRewardEarnedListener
- A functional interface for listening to reward events.
- ScreenAdContentCallback
- A callback class for handling events related to ad content.
- TargetingOptions
- The App/user targeting options.
Enums
- AdChoicesPlacement
- Indicates preferred location of AdChoices icon.
- AdFormat
- This class defines a format of an ad.
- AdRevenuePrecision
- Defines the precision levels for ad revenue calculations. These levels indicate the accuracy or source of the revenue data provided by the system.
- AdType
- Audience
- Prohibition on Personal Information from Children
- CCPAStatus
- ConsentStatus
- User consent status
- Gender
- User gender values.
- LoadingMode
- NativeTemplateFontStyle
- Font types for native templates.
- PriceAccuracy
- PrivacyGeography
- User's geography for determining consent flow.
Typedefs
- BannerView = BannerWidget
- BannerViewState = BannerWidgetState
- OnAdCallback = void Function(AdInstance ad)
- The callback type to handle an event occurring for an AdInstance.
- OnAdContentCallback = void Function(AdInstance ad, AdContentInfo contentInfo)
- The callback type for when an ad impression occurs.
- OnAdFailedCallback = void Function(AdInstance ad, AdError error)
- The callback type to handle an error loading/showing an AdInstance.
- OnAdViewCallback = void Function(AdViewInstance adView)
- The callback type to handle an event occurring for an AdViewInstance.
- OnConsentFlowDismissedCallback = void Function(int status)
-
The callback type for when a user earns a reward.
Check
statuswith ConsentFlow status constants. - OnScreenAdCallback = void Function(AdScreenInstance screenAd)
- The callback type to handle an event occurring for an AdScreenInstance.