codeTimeout constant
int
const codeTimeout
Indicates a timeout error occurred because the advertising source did not respond in time. The system will continue waiting for a response, which may delay ad loading or cause a loading error.
Implementation
static const int codeTimeout = 8;