setAutoloadEnabled method
Gets or sets whether auto loading of ads is enabled.
If enabled, the ad will automatically load new content when the current ad is dismissed or completed. Additionally, it will automatically retry loading the ad if an error occurs during the loading process.
Implementation
Future<void> setAutoloadEnabled(bool isEnabled) {
return casInternalBridge.setAutoloadEnabled(this, isEnabled);
}