targetingOptions property
You can now easily tailor the way you serve your ads to fit a specific audience! You’ll need to inform our servers of the users’ details so the SDK will know to serve ads according to the segment the user belongs to.
Implementation
@Deprecated("Replaced to CASMobileAds.targetingOptions")
static TargetingOptions get targetingOptions {
return CASMobileAds.targetingOptions;
}