InitializationStatus class
The status of the SDK initialization.
Constructors
- InitializationStatus({required String? error, required String? countryCode, required bool isPrivacyOptionsRequired, required int consentFlowStatus})
- Default constructor to create an InitializationStatus.
Properties
- consentFlowStatus → int
-
Consent flow status code. Check constant codes from ConsentFlow class.
final
- countryCode → String?
-
User Country code ISO 2 or null if not allowed.
final
- error → String?
-
Initialization error or null if success.
Check error with InitializationStatus error constants.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- isPrivacyOptionsRequired → bool
-
Indicates the privacy options button is required.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Constants
- errorNoConnection → const String
- Indicates that device network connection is not stable enough.
- errorNotRegisteredId → const String
- Indicates that the CAS ID is not registered in system. Contact support to clarify the reasons.
- errorServer → const String
- Indicates a temporary problem with the server. If the error could be 100% replicated, please give feedback to us.
- errorVerification → const String
- Indicates that the SDK version is no longer compatible. Please update to the latest SDK.