NativeTemplateStyle class
Style options for native templates.
Can be used when loading a CASNativeContent.
Constructors
- NativeTemplateStyle({Color? backgroundColor, Color? primaryColor, Color? primaryTextColor, Color? headlineTextColor, NativeTemplateFontStyle? headlineFontStyle, Color? secondaryTextColor, NativeTemplateFontStyle? secondaryFontStyle})
- Create a NativeTemplateStyle.
Properties
- backgroundColor → Color?
-
The background color.
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- headlineFontStyle → NativeTemplateFontStyle?
-
The Headline text font style.
final
- headlineTextColor → Color?
-
The Headline text color.
final
- primaryColor → Color?
-
The primary color for Call to action button background.
final
- primaryTextColor → Color?
-
The text color for Call To Action button.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- secondaryFontStyle → NativeTemplateFontStyle?
-
The Secondary (other) text font style.
final
- secondaryTextColor → Color?
-
The Secondary (other) text color.
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited