onAdClicked property
Called when the ad content is clicked by the user.
This function provides an opportunity to handle user clicks on the ad, such as tracking click events or updating the UI.
ad The ad content that was clicked by the user.
Implementation
final void Function(AdContentInfo ad)? onAdClicked;