onAdFailedToLoad property
Called when the ad content fails to load.
This function provides an opportunity to handle loading failures, such as displaying an error message to the user or attempting to load a different ad.
format The format of ad content.
error The error that occurred while attempting to load the ad content.
Implementation
final void Function(AdFormat format, AdError error)? onAdFailedToLoad;