onAdLoaded property
Called when the ad content has been successfully loaded.
This function provides an opportunity to handle successful ad loading, such as preparing the ad for display.
ad The ad content that has been successfully loaded.
Implementation
final void Function(AdContentInfo ad)? onAdLoaded;