onAdShowed property
Called when the ad content is successfully shown.
This function is triggered when the ad content has been successfully displayed. Use this function to perform any actions required after the ad is shown, such as logging or UI updates.
ad The ad content that has been successfully shown.
Implementation
final void Function(AdContentInfo ad)? onAdShowed;